@@ -70,7 +70,7 @@ from isso.views import comments
 
 from isso.ext.notifications import Stdout, SMTP
 
-logging.getLogger('werkzeug').setLevel(logging.ERROR)
+logging.getLogger('werkzeug').setLevel(logging.WARN)
 logging.basicConfig(
     level=logging.INFO,
     format="%(asctime)s %(levelname)s: %(message)s")
@@ -232,6 +232,15 @@ def main():
 
         sys.exit(0)
 
+    if conf.get("general", "log-file"):
+        handler = logging.FileHandler(conf.get("general", "log-file"))
+
+        logger.addHandler(handler)
+        logging.getLogger("werkzeug").addHandler(handler)
+
+        logger.propagate = False
+        logging.getLogger("werkzeug").propagate = False
+
     if not any(conf.getiter("general", "host")):
         logger.error("No website(s) configured, Isso won't work.")
         sys.exit(1)
