@@ -1021,7 +1021,7 @@ define('app/i18n/fr',{
     "comment-queued": "Commentaire en attente de modération.",
     "comment-anonymous": "Anonyme",
     "comment-hidden": "1 caché\n{{ n }} cachés",
-    "date-now": "À l'instant'",
+    "date-now": "À l'instant",
     "date-minute": "Il y a une minute\nIl y a {{ n }} minutes",
     "date-hour": "Il y a une heure\nIl y a {{ n }} heures ",
     "date-day": "Hier\nIl y a {{ n }} jours",
